==> enchaintesdk-0.1.0.tar.gz: enchaintesdk-0.1.0/enchaintesdk/infrastructure/http/http_client.py <==
import requests
from .http_data import HttpData
from .dto.api_response_entity import ApiResponse
from .exception.http_exception import HttpRequestException
from requests.exceptions import RequestException


class HttpClient:

    def __init__(self, http_data: HttpData):
        self.__http_data = http_data

    def setApiKey(self, api_key: str):
        self.__http_data.api_key = api_key

    def get(self, url: str, headers={}):
        ''' Wrapper for request library. Can raise HttpRequestException. '''
        try:
            new_headers = dict(
                {"Authorization": self.__http_data.api_key}, **headers)
            response = requests.get(url=url, headers=new_headers)
            response_json = response.json()
            if response.ok:
                return ApiResponse(response_json)
            raise HttpRequestException(response_json['error']['message'])
        except RequestException as e:
            raise HttpRequestException(str(e))

    def post(self, url: str, body, headers={}):
        ''' Wrapper for request library. Can raise HttpRequestException. '''
        try:
            new_headers = dict(
                {"Authorization": 'Bearer ' + self.__http_data.api_key}, **headers)
            response = requests.post(url=url, json=body, headers=new_headers)
            response_json = response.json()
            if response.ok:
                return ApiResponse(response_json)
            raise HttpRequestException(response_json['error']['message'])
        except RequestException as e:
            raise HttpRequestException(str(e))

==> enchaintesdk-0.1.3.tar.gz: enchaintesdk-0.1.3/enchaintesdk/infrastructure/http/http_client.py <==
from requests.exceptions import RequestException
import requests
from .http_data import HttpData
from .dto.api_response_entity import ApiResponse
from .http_exception import HttpRequestException


class HttpClient:

    def __init__(self, http_data: HttpData):
        self.__http_data = http_data

    def setApiKey(self, api_key: str):
        self.__http_data.api_key = api_key

    def get(self, url: str, headers={}):
        ''' Wrapper for request library. Can raise HttpRequestException. '''
        try:
            new_headers = dict(
                {"X-API-KEY": self.__http_data.api_key}, **headers)
            response = requests.get(url=url, headers=new_headers)
            response_json = response.json()
            if response.ok:
                return response_json
            raise HttpRequestException(response_json['message'])
        except RequestException as e:
            raise HttpRequestException(str(e))

    def post(self, url: str, body, headers={}):
        ''' Wrapper for request library. Can raise HttpRequestException. '''
        try:
            new_headers = dict(
                {"X-API-KEY": self.__http_data.api_key}, **headers)
            response = requests.post(url=url, json=body, headers=new_headers)
            response_json = response.json()
            if response.ok:
                return response_json
            raise HttpRequestException(response_json['message'])
        except RequestException as e:
            raise HttpRequestException(str(e))
